@@ -16,8 +16,6 @@
 
 import os
 
-import inspect
-
 import six
 import testtools
 
@@ -28,12 +26,11 @@ from bandit.core import metrics
 from bandit.core import test_set as b_test_set
 
 
-cfg_file = os.path.join(os.getcwd(), 'bandit/config/bandit.yaml')
-
-
 class FunctionalTests(testtools.TestCase):
 
-    '''This set of tests runs bandit against each example file in turn
+    '''Functional tests for bandit test plugins.
+
+    This set of tests runs bandit against each example file in turn
     and records the score returned. This is compared to a known good value.
     When new tests are added to an example the expected result should be
     adjusted to match.
@@ -45,7 +42,7 @@ class FunctionalTests(testtools.TestCase):
         # them up here for the testing environment.
         #
         path = os.path.join(os.getcwd(), 'bandit', 'plugins')
-        b_conf = b_config.BanditConfig(cfg_file)
+        b_conf = b_config.BanditConfig()
         self.b_mgr = b_manager.BanditManager(b_conf, 'file')
         self.b_mgr.b_conf._settings['plugins_dir'] = path
         self.b_mgr.b_ts = b_test_set.BanditTestSet(config=b_conf)
@@ -116,12 +113,14 @@ class FunctionalTests(testtools.TestCase):
 
     def test_crypto_md5(self):
         '''Test the `hashlib.md5` example.'''
-        expect = {'SEVERITY': {'MEDIUM': 8}, 'CONFIDENCE': {'HIGH': 8}}
+        expect = {'SEVERITY': {'MEDIUM': 8},
+                  'CONFIDENCE': {'HIGH': 8}}
         self.check_example('crypto-md5.py', expect)
 
     def test_ciphers(self):
         '''Test the `Crypto.Cipher` example.'''
-        expect = {'SEVERITY': {'LOW': 1, 'HIGH': 8}, 'CONFIDENCE': {'HIGH': 9}}
+        expect = {'SEVERITY': {'HIGH': 8},
+                  'CONFIDENCE': {'HIGH': 8}}
         self.check_example('ciphers.py', expect)
 
     def test_cipher_modes(self):
@@ -156,7 +155,7 @@ class FunctionalTests(testtools.TestCase):
         self.check_example('hardcoded-passwords.py', expect)
 
     def test_hardcoded_tmp(self):
-        '''Test for hard-coded /tmp, /var/tmp, /dev/shm'''
+        '''Test for hard-coded /tmp, /var/tmp, /dev/shm.'''
         expect = {'SEVERITY': {'MEDIUM': 3}, 'CONFIDENCE': {'MEDIUM': 3}}
         self.check_example('hardcoded-tmp.py', expect)
 
@@ -251,7 +250,7 @@ class FunctionalTests(testtools.TestCase):
         '''Test for the `pickle` module.'''
         expect = {
             'SEVERITY': {'LOW': 2, 'MEDIUM': 6},
-            'CONFIDENCE': {'HIGH': 8 }
+            'CONFIDENCE': {'HIGH': 8}
         }
         self.check_example('pickle_deserialize.py', expect)
 
@@ -276,7 +275,7 @@ class FunctionalTests(testtools.TestCase):
         self.check_example('skip.py', expect)
 
     def test_ignore_skip(self):
-        ''' Test --ignore-nosec flag.'''
+        '''Test --ignore-nosec flag.'''
         expect = {'SEVERITY': {'LOW': 7}, 'CONFIDENCE': {'HIGH': 7}}
         self.check_example('skip.py', expect, ignore_nosec=True)
 
@@ -319,7 +318,7 @@ class FunctionalTests(testtools.TestCase):
     def test_wildcard_injection(self):
         '''Test for wildcard injection in shell commands.'''
         expect = {
-            'SEVERITY': {'HIGH': 4, 'MEDIUM':4, 'LOW': 6},
+            'SEVERITY': {'HIGH': 4, 'MEDIUM': 4, 'LOW': 6},
             'CONFIDENCE': {'MEDIUM': 5, 'HIGH': 9}
         }
         self.check_example('wildcard-injection.py', expect)
@@ -333,7 +332,7 @@ class FunctionalTests(testtools.TestCase):
         '''Test jinja templating for potential XSS bugs.'''
         expect = {
             'SEVERITY': {'HIGH': 4},
-            'CONFIDENCE': {'HIGH': 3, 'MEDIUM':1}
+            'CONFIDENCE': {'HIGH': 3, 'MEDIUM': 1}
         }
         self.check_example('jinja2_templating.py', expect)
 
@@ -384,8 +383,8 @@ class FunctionalTests(testtools.TestCase):
                   'CONFIDENCE': {'HIGH': 2, 'MEDIUM': 2}}
         self.check_example('xml_minidom.py', expect)
 
-        expect = {'SEVERITY': {'LOW': 1, 'HIGH': 6},
-                  'CONFIDENCE': {'HIGH': 1, 'MEDIUM': 6}}
+        expect = {'SEVERITY': {'LOW': 2, 'HIGH': 6},
+                  'CONFIDENCE': {'HIGH': 2, 'MEDIUM': 6}}
         self.check_example('xml_sax.py', expect)
 
     def test_asserts(self):
@@ -407,29 +406,41 @@ class FunctionalTests(testtools.TestCase):
 
         self.check_example('partial_path_process.py', expect)
 
+    def test_try_except_continue(self):
+        '''Test try, except, continue detection.'''
+        test = next((x for x in self.b_mgr.b_ts.tests['ExceptHandler']
+                    if x.__name__ == 'try_except_continue'))
+
+        test._config = {'check_typed_exception': True}
+        expect = {'SEVERITY': {'LOW': 3}, 'CONFIDENCE': {'HIGH': 3}}
+        self.check_example('try_except_continue.py', expect)
+
+        test._config = {'check_typed_exception': False}
+        expect = {'SEVERITY': {'LOW': 2}, 'CONFIDENCE': {'HIGH': 2}}
+        self.check_example('try_except_continue.py', expect)
+
     def test_try_except_pass(self):
         '''Test try, except pass detection.'''
-        expect = {'SEVERITY': {'LOW': 3},
-                  'CONFIDENCE': {'HIGH': 3}}
+        test = next((x for x in self.b_mgr.b_ts.tests['ExceptHandler']
+                     if x.__name__ == 'try_except_pass'))
 
+        test._config = {'check_typed_exception': True}
+        expect = {'SEVERITY': {'LOW': 3}, 'CONFIDENCE': {'HIGH': 3}}
         self.check_example('try_except_pass.py', expect)
 
-        conf = self.b_mgr.b_conf._config
-        conf['try_except_pass']['check_typed_exception'] = False
-        expect = {'SEVERITY': {'LOW': 2},
-                  'CONFIDENCE': {'HIGH': 2}}
-
+        test._config = {'check_typed_exception': False}
+        expect = {'SEVERITY': {'LOW': 2}, 'CONFIDENCE': {'HIGH': 2}}
         self.check_example('try_except_pass.py', expect)
 
     def test_metric_gathering(self):
         expect = {
             'nosec': 2, 'loc': 7,
-            'issues': { 'CONFIDENCE': {'HIGH': 5}, 'SEVERITY': {'LOW': 5} }
+            'issues': {'CONFIDENCE': {'HIGH': 5}, 'SEVERITY': {'LOW': 5}}
         }
         self.check_metrics('skip.py', expect)
         expect = {
             'nosec': 0, 'loc': 4,
-            'issues': { 'CONFIDENCE': {'HIGH': 2}, 'SEVERITY': {'LOW': 2} }
+            'issues': {'CONFIDENCE': {'HIGH': 2}, 'SEVERITY': {'LOW': 2}}
         }
         self.check_metrics('imports.py', expect)
 
@@ -459,9 +470,19 @@ class FunctionalTests(testtools.TestCase):
         self.assertEqual(list(range(1, 3)), issues[0].linerange)
         self.assertIn('subprocess', issues[0].get_code())
         self.assertEqual(5, issues[1].lineno)
-        self.assertEqual(list(range(3, 6+1)), issues[1].linerange)
+        self.assertEqual(list(range(3, 6 + 1)), issues[1].linerange)
         self.assertIn('shell=True', issues[1].get_code())
 
+    def test_code_line_numbers(self):
+        self.run_example('binding.py')
+        issues = self.b_mgr.get_issue_list()
+
+        code_lines = issues[0].get_code().splitlines()
+        lineno = issues[0].lineno
+        self.assertEqual("%i " % (lineno - 1), code_lines[0][:2])
+        self.assertEqual("%i " % (lineno), code_lines[1][:2])
+        self.assertEqual("%i " % (lineno + 1), code_lines[2][:2])
+
     def test_flask_debug_true(self):
         expect = {
             'SEVERITY': {'HIGH': 1},
@@ -469,7 +490,17 @@ class FunctionalTests(testtools.TestCase):
         }
         self.check_example('flask_debug.py', expect)
 
+    def test_nosec(self):
+        expect = {
+            'SEVERITY': {},
+            'CONFIDENCE': {}
+        }
+        self.check_example('nosec.py', expect)
+
     def test_baseline_filter(self):
+        issue_text = ('A Flask app appears to be run with debug=True, which '
+                      'exposes the Werkzeug debugger and allows the execution '
+                      'of arbitrary code.')
         json = """{
           "results": [
             {
@@ -477,16 +508,17 @@ class FunctionalTests(testtools.TestCase):
               "filename": "%s/examples/flask_debug.py",
               "issue_confidence": "MEDIUM",
               "issue_severity": "HIGH",
-              "issue_text": "A Flask app appears to be run with debug=True, which exposes the Werkzeug debugger and allows the execution of arbitrary code.",
+              "issue_text": "%s",
               "line_number": 10,
               "line_range": [
                 10
               ],
-              "test_name": "flask_debug_true"
+              "test_name": "flask_debug_true",
+              "test_id": "B201"
             }
           ]
         }
-        """ % os.getcwd()
+        """ % (os.getcwd(), issue_text)
 
         self.b_mgr.populate_baseline(json)
         self.run_example('flask_debug.py')
