@@ -1,6 +1,21 @@
+# Copyright (c) 2015 VMware, Inc.
+#
+#  Licensed under the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License. You may obtain
+#  a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#  License for the specific language governing permissions and limitations
+#  under the License.
+
 import os
-import six
 import subprocess
+
+import six
 import testtools
 
 
@@ -19,10 +34,6 @@ class RuntimeTests(testtools.TestCase):
         return (retcode, stdout.decode('utf-8'))
 
     def _test_example(self, cmdlist, targets):
-        cmdlist.extend([
-            '-c',
-            os.path.join(os.getcwd(), 'bandit', 'config', 'bandit.yaml')
-        ])
         for t in targets:
             cmdlist.append(os.path.join(os.getcwd(), 'examples', t))
         return self._test_runtime(cmdlist)
@@ -41,16 +52,30 @@ class RuntimeTests(testtools.TestCase):
             'bandit', '-c', 'nonexistent.yml', 'xx.py'
         ])
         self.assertEqual(2, retcode)
-        self.assertIn("Could not open config file: nonexistent.yml", output)
+        self.assertIn("nonexistent.yml : Could not read config file.", output)
 
     def test_help_arg(self):
         (retcode, output) = self._test_runtime(['bandit', '-h'])
         self.assertEqual(0, retcode)
-        self.assertIn("Bandit - a Python source code analyzer.", output)
+        self.assertIn(
+            "Bandit - a Python source code security analyzer", output
+        )
         self.assertIn("usage: bandit [-h]", output)
         self.assertIn("positional arguments:", output)
         self.assertIn("optional arguments:", output)
-        self.assertIn("plugin suites were discovered and loaded:", output)
+        self.assertIn("tests were discovered and loaded:", output)
+
+    def test_help_in_readme(self):
+        replace_list = [' ', '\t']
+        (retcode, output) = self._test_runtime(['bandit', '-h'])
+        for i in replace_list:
+            output = output.replace(i, '')
+        output = output.replace("'", "\'")
+        with open('README.rst') as f:
+            readme = f.read()
+            for i in replace_list:
+                readme = readme.replace(i, '')
+            self.assertIn(output, readme)
 
     # test examples (use _test_example() to wrap in config location argument
     def test_example_nonexistent(self):
@@ -81,6 +106,7 @@ class RuntimeTests(testtools.TestCase):
         self.assertIn("Low: 2", output)
         self.assertIn("High: 2", output)
         self.assertIn("Files skipped (0):", output)
-        self.assertIn("Issue: [blacklist_imports] Consider possible", output)
-        self.assertIn("imports.py:2\n", output)
-        self.assertIn("imports.py:4\n", output)
+        self.assertIn("Issue: [B403:blacklist] Consider possible",
+                      output)
+        self.assertIn("imports.py:2", output)
+        self.assertIn("imports.py:4", output)
